//////////////////////////////////////////////////////////////////////////
// Copyright 2005-2008 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Editor. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////

#if ASPOSE_EDITOR_DESKTOP
namespace Aspose.Editor.Desktop
#elif ASPOSE_EDITOR_CLIENT
namespace Aspose.Editor.Client
#endif
{
    /// <summary>
    /// Provides integration of the Keyoti RapidSpell for .NET with Aspose.Editor control.
    /// </summary>
    /// <remarks>
    /// This class provides two methods for integration. In web applications you can use it as a plugin,
    /// in desktop applications you can also install adapter directly from the application code.
    /// Using it as a plugin is preferred in both cases, please consult programmers guide for details.
    /// </remarks>
    /// <example>
    /// This is an example for desktop application. In order to enable spell checking functionality in the
    /// Aspose.Editor it is required to add single line of code right after the Aspose.Editor instance is created.
    /// <code>
    /// // Editor conrol is created.
    /// mEditor = new EditorControl();
    /// // Adapter is installed. The line below is the only line required. Make sure it's not called twice.
    /// KeyotiRapidSpellAdapter.Install(mEditor);
    /// </code>
    /// </example>
    [Aspose.Editor.PluginClass("Keyoti RapidSpell Adapter", "Integrates Keyoti RapidSpell Desktop spell checker control.")]
    public class KeyotiRapidSpellAdapter
    {
        /// <summary>
        /// Installs the adapter within the specified editor control. This method shall be called once
        /// for each editor control. After this method is called changing <see cref="IsInstallSpellAsYouType"/>
        /// and <see cref="IsInstallSpellDialog"/> properties doesn't affect the installed adapter.
        /// </summary>
        /// <remarks>If this method is called multiple times for the same control then results are
        /// unpredictable.</remarks>
        public static void Install(EditorControl editorControl)
        {
            //3C3B3C453B40403E4348316B6E6B354B52513838417
            Keyoti.RapidSpell.ComClientInteropSupport c = new Keyoti.RapidSpell.ComClientInteropSupport();
            c.Key = "3C3B3C453B40413E4348316B6E6B35514C513D3B416";

            // Here we create instance of the adapter. It will create commands in the editor and thus
            // until editor is released adapter stays alive. We dont have to keep reference onto adapter.
            new KeyotiRapidSpellAdapterImpl(editorControl, IsInstallSpellDialog,IsInstallSpellAsYouType, IsSpellAsYouTypeEnabledByDefault);
        }


        /// <summary>
        /// This constructor is called automatically by the editor if adapter is loaded as a plug-in module.
        /// </summary>
        public KeyotiRapidSpellAdapter(EditorControl editor)
        {
            Install(editor);
        }


        /// <summary>
        /// Gets or sets indication of whether spell dialog shall be installed.
        /// </summary>
        /// <remarks>This property must be set before <see cref="Install"/> is called.</remarks>
        public static bool IsInstallSpellDialog
        {
            get { return mIsInstallSpellDialog; }
            set { mIsInstallSpellDialog = value; }
        }


        /// <summary>
        /// Gets or sets indication of whether check spelling as you type feature shall be installed.
        /// </summary>
        /// <remarks>This property must be set before <see cref="Install"/> is called.</remarks>
        public static bool IsInstallSpellAsYouType
        {
            get { return mIsInstallSpellAsYouType; }
            set { mIsInstallSpellAsYouType = value; }
        }


        /// <summary>
        /// Gets or sets indication of whether check spelling as you type feature is
        /// enabled by default when editor is shown.
        /// </summary>
        /// <remarks>This property only specifies initial state of the feature, however
        /// user can enable and disable it at runtime.</remarks>
        public static bool IsSpellAsYouTypeEnabledByDefault
        {
            get { return mIsSpellAsYouTypeEnabledByDefault; }
            set { mIsSpellAsYouTypeEnabledByDefault = value; }
        }


        private static bool mIsInstallSpellAsYouType = true;

        private static bool mIsInstallSpellDialog = true;

        private static bool mIsSpellAsYouTypeEnabledByDefault = true;
    }
}